==> 0.0.3.tar.gz: android/src/main/kotlin/com/ahazou/watermark_shareable/WatermarkShareablePlugin.kt <==
package com.ahazou.watermark_shareable

import android.annotation.TargetApi
import android.app.Activity
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Canvas
import android.graphics.drawable.Drawable
import android.media.Image
import android.net.Uri
import android.os.Build
import android.util.Log
import androidx.annotation.NonNull
import androidx.annotation.RequiresApi
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.io.ByteArrayOutputStream
import java.lang.ref.WeakReference
import java.net.URL
import com.squareup.picasso.Picasso
import java.io.File

/** WatermarkShareablePlugin */
public class WatermarkShareablePlugin: FlutterPlugin, MethodCallHandler, ActivityAware
{

  companion object {
    lateinit var activity: WeakReference<Activity>
    lateinit var bitmap: Any
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "watermark_shareable")
      channel.setMethodCallHandler(WatermarkShareablePlugin())
    }
  }

  private lateinit var channel : MethodChannel
  lateinit var signaturePost: Drawable

  override fun onDetachedFromActivity() {}

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {}

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = WeakReference(binding.activity)
  }

  override fun onDetachedFromActivityForConfigChanges() {}

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "watermark_shareable")
    channel.setMethodCallHandler(this);
  }



  @RequiresApi(Build.VERSION_CODES.LOLLIPOP)
  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when ( call.method ) {
      "getPostWithWaterMark" -> {
        val args = call.arguments as String
        bitmap = getPostWithWaterMark(args)
        result.success(bitmap)
      }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }


  @RequiresApi(Build.VERSION_CODES.LOLLIPOP)
  private fun getPostWithWaterMark(image: String): ByteArray {
    val uri = Uri.parse(image)
    val file = File(uri.path)
    val myBitmap = BitmapFactory.decodeFile(file.path)
    try{
      signaturePost = activity.get()!!.applicationContext.getDrawable(R.drawable.water_mark_free)
      val imageWaterMark = Constants.drawableToBitmap(signaturePost)
      val imageWithWaterMark = Constants.overlay(myBitmap, imageWaterMark)

      val stream = ByteArrayOutputStream()
      imageWithWaterMark.compress(Bitmap.CompressFormat.PNG, 100, stream)
      val byteArray: ByteArray = stream.toByteArray()
      return byteArray
    }catch (e: Exception){
      val stream = ByteArrayOutputStream()
      val byteArray: ByteArray = stream.toByteArray()
      e.stackTrace
      return byteArray
    }

  }

}

==> 0.0.4.tar.gz: android/src/main/kotlin/com/ahazou/watermark_shareable/WatermarkShareablePlugin.kt <==
package com.ahazou.watermark_shareable

import android.annotation.TargetApi
import android.app.Activity
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Canvas
import android.graphics.drawable.Drawable
import android.media.Image
import android.net.Uri
import android.os.Build
import android.util.Log
import androidx.annotation.NonNull
import androidx.annotation.RequiresApi
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.io.ByteArrayOutputStream
import java.lang.ref.WeakReference
import java.net.URL
import com.squareup.picasso.Picasso
import java.io.File

/** WatermarkShareablePlugin */
public class WatermarkShareablePlugin: FlutterPlugin, MethodCallHandler, ActivityAware
{

  companion object {
    lateinit var activity: WeakReference<Activity>
    lateinit var bitmap: Any
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "watermark_shareable")
      channel.setMethodCallHandler(WatermarkShareablePlugin())
    }
  }

  private lateinit var channel : MethodChannel
  lateinit var signaturePost: Drawable

  override fun onDetachedFromActivity() {}

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {}

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = WeakReference(binding.activity)
  }

  override fun onDetachedFromActivityForConfigChanges() {}

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "watermark_shareable")
    channel.setMethodCallHandler(this);
  }



  @RequiresApi(Build.VERSION_CODES.LOLLIPOP)
  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when ( call.method ) {
      "getPostWithWaterMark" -> {
        val args = call.arguments as Map<*, *>
        bitmap = getPostWithWaterMark(args["image"] as String, args["type"] as String)
        result.success(bitmap)
      }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }


  @RequiresApi(Build.VERSION_CODES.LOLLIPOP)
  private fun getPostWithWaterMark(image: String, type: String): ByteArray {
    val uri = Uri.parse(image)
    val file = File(uri.path)
    val myBitmap = BitmapFactory.decodeFile(file.path)
    try{
      if(type == "post"){
        signaturePost = activity.get()!!.applicationContext.getDrawable(R.drawable.water_mark_free_post)
      }else if(type == "stories"){
        signaturePost = activity.get()!!.applicationContext.getDrawable(R.drawable.water_mark_free_storie)
      }else{
        signaturePost = activity.get()!!.applicationContext.getDrawable(R.drawable.water_mark_free)
      }

      val imageWaterMark = Constants.drawableToBitmap(signaturePost)
      val imageWithWaterMark = Constants.overlay(myBitmap, imageWaterMark)

      val stream = ByteArrayOutputStream()
      imageWithWaterMark.compress(Bitmap.CompressFormat.PNG, 100, stream)
      val byteArray: ByteArray = stream.toByteArray()
      return byteArray
    }catch (e: Exception){
      val stream = ByteArrayOutputStream()
      val byteArray: ByteArray = stream.toByteArray()
      e.stackTrace
      return byteArray
    }

  }

}
